@@ -1,5 +1,5 @@
 /*$Id:$*/
-/*06.11.2024	24.11.2003	Белых А.И.	iceb_l_kontr.c
+/*27.12.2026	24.11.2003	Белых А.И.	iceb_l_kontr.c
 Работа с общим списком контрагентов
 Если вернули 0- выбрали контрагента
              1- нет
@@ -199,11 +199,14 @@ gtk_box_pack_start (GTK_BOX (hbox), vbox2, TRUE, TRUE, 0);
 data.label_kolstr=gtk_label_new (gettext("Общий список контрагентов"));
 
 
-gtk_box_pack_start (GTK_BOX (vbox2),data.label_kolstr,FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX(vbox2),data.label_kolstr,FALSE, FALSE, 0);
 
-data.label_poisk=gtk_label_new (gettext("Ждите !"));
+//data.label_poisk=gtk_label_new(gettext("Ждите !!!"));
+data.label_poisk=gtk_label_new(NULL);
+iceb_label_set_style_text(data.label_poisk,"font-family=\"monospace\" color=\"red\"",gettext("Ждите !!!"));
+iceb_set_blinking_text(data.label_poisk);
 
-gtk_box_pack_start (GTK_BOX (vbox2),data.label_poisk,FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX(vbox2),data.label_poisk,FALSE, FALSE, 0);
 
 data.sw = gtk_scrolled_window_new (NULL, NULL);
 
@@ -306,10 +309,10 @@ if(data.metka_rr == 0)
 
 gtk_widget_show_all(data.window);
 
+gtk_widget_hide(data.label_poisk); 
 
 //gtk_window_fullscreen(GTK_WINDOW(data.window));
 
-//gtk_widget_hide (data.label_poisk);
 
 gtk_main();
 
@@ -531,8 +534,9 @@ if(data->poisk.metka_poi == 1)
   gtk_widget_show(data->label_poisk);
  }
 else
- gtk_widget_hide(data->label_poisk); 
-
+ {
+  gtk_widget_hide(data->label_poisk); 
+ }
 
 //gdk_window_set_cursor(gtk_widget_get_window(data->window),gdk_cursor_new_for_display(gtk_widget_get_display(data->window),ICEB_CURSOR));
 //printf("kontr_create_list - end\n");
