@@ -187,7 +187,10 @@ data.label_kolstr=gtk_label_new (gettext("Общий список контраг
 
 gtk_box_pack_start (GTK_BOX (vbox2),data.label_kolstr,FALSE, FALSE, 0);
 
-data.label_poisk=gtk_label_new ("");
+//data.label_poisk=gtk_label_new ("");
+data.label_poisk=gtk_label_new(NULL);
+iceb_label_set_style_text(data.label_poisk,"font-family=\"monospace\" color=\"red\"",gettext("Ждите !!!"));
+iceb_set_blinking_text(data.label_poisk);
 
 gtk_box_pack_start (GTK_BOX (vbox2),data.label_poisk,FALSE, FALSE, 0);
 
