@@ -1,5 +1,5 @@
 /*$Id:$*/
-/*03.11.2023	07.09.2003	Белых А.И.	iceb_libbuhg.h
+/*25.12.2025	07.09.2003	Белых А.И.	iceb_libbuhg.h
 */
 #include <stdlib.h>
 #include <glib.h>
@@ -152,6 +152,8 @@ class iceb_akt_sverki //Для расчёта акта сверки по кон
 
 
 
+void iceb_set_blinking_text(GtkWidget *label);
+void iceb_printw_from_thread(class iceb_printw_from_thread_data *data);
 int iceb_dirfajl(const char *name,int mi,class iceb_u_spisok *mfa,GtkWidget *wpredok);
 void iceb_dirlst(const char *tfima,GtkWidget *wpredok);
 void      iceb_msql_error(SQL_baza*,const char*,const char*,GtkWidget*);
@@ -206,7 +208,10 @@ void	 iceb_zagsh(const char *shet,FILE *ff,GtkWidget*);
 void      iceb_salorksl(double dd, double kk,double ddn,double kkn,double debm,double krem,FILE *ff1,FILE *ffact);
 void      iceb_printw(const char *stroka,GtkTextBuffer *buffer,GtkWidget *view);
 void iceb_printw(const char *stroka,GtkTextBuffer *buffer,GtkWidget *view,const char *name_tag);
+
 void      iceb_printw_vr(time_t vrem_n,GtkTextBuffer *buffer,GtkWidget *view);
+void iceb_printw_vr(time_t vrem_n,class iceb_printw_from_thread_data *data);
+
 int       iceb_prsh(const char*,OPSHET *,GtkWidget*);
 int       iceb_prsh1(const char *shet,OPSHET *shetv,GtkWidget *wpredok);
 int       iceb_prsh1(const char *shet,GtkWidget *wpredok);
@@ -232,7 +237,6 @@ int       iceb_sql_readkey(const char *zapros,SQL_str *row,SQLCURSOR *cur,GtkWid
 int       iceb_sql_readkey(const char *zapros,GtkWidget *wpredok);
 void      iceb_printcod(FILE *,const char *,const char *,const char *,int,const char *,int *);
 int       iceb_rsn(class SYSTEM_NAST *data,GtkWidget *wpredok);
-//void      iceb_l_rsfr(GtkWidget *wpredok);
 int       iceb_rmenuf(char *imafil,iceb_u_spisok *kol1,iceb_u_spisok *kol2,GtkWidget *wpredok);
 int       iceb_l_spisokm(iceb_u_spisok *kol1,iceb_u_spisok *kol2,iceb_u_spisok *naim_kol,iceb_u_str*,int nom_str,GtkWidget *wpredok);
 int   iceb_smenabaz(int mopen,GtkWidget *wpredok);
@@ -420,10 +424,7 @@ void iceb_rnfxml(class iceb_rnfxml_data *rek_zag_nn,GtkWidget *wpredok);
 
 int iceb_openxml(short dn,short mn,short gn,short dk,short mk,short gk,char *imaf_xml,const char *kod_dok,int nomer_dok_v_pakete,int *period_type,class iceb_rnfxml_data *rek_zag_nn,FILE **ff_xml,GtkWidget *wpredok);
 int iceb_openxml(const char *datan,const char *datak,char *imaf_xml,const char *kod_dok,int nomer_dok_v_pakete,int *period_type,class iceb_rnfxml_data *rek_zag_nn,FILE **ff_xml,GtkWidget *wpredok);
-/***********
-int iceb_openxml(short dn,short mn,short gn,short dk,short mk,short gk,char *imaf_xml,const char *tip_dok,const char *pod_tip_dok,const char *nomer_versii_dok,int nomer_dok_v_pakete,int *period_type,class iceb_rnfxml_data *rek_zag_nn,FILE **ff_xml,GtkWidget *wpredok);
-int iceb_openxml(const char *datan,const char *datak,char *imaf_xml,const char *tip_dok,const char *pod_tip_dok,const char *nomer_versii_dok,int nomer_dok_v_pakete,int *period_type,class iceb_rnfxml_data *rek_zag_nn,FILE **ff_xml,GtkWidget *wpredok);
-****************/
+
 int iceb_menu_vibkat(class iceb_u_spisok *zapros,class iceb_u_str *stroka,GtkWidget *wpredok);
 int iceb_menu_vibkat(const char *zapros,class iceb_u_str *stroka,GtkWidget *wpredok);
 const char *iceb_get_pnk(const char *kodkontr,int metka,GtkWidget *wpredok);
@@ -446,13 +447,13 @@ void iceb_zagolov(const char *naim,const char *datan,const char *datak,FILE *ff,
 
 void iceb_rnn_sap_xml(short gn,short mk,const char *kod_dok,int pnd,int period_type,class iceb_rnfxml_data *rek_zag_nn,FILE *ff_xml);
 void iceb_rnn_sap_xml(const char *datan,const char *datak,const char *kod_dok,int pnd,int period_type,class iceb_rnfxml_data *rek_zag_nn,FILE *ff_xml);
-/*****************
-void iceb_rnn_sap_xml(short mn,short gn,short mk,const char *tip_dok,const char *podtip,int type_ver,int pnd,const char *imaf,int period_type,class iceb_rnfxml_data *rek_zag_nn,FILE *ff_xml);
-void iceb_rnn_sap_xml(const char *datan,const char *datak,const char *tip_dok,const char *podtip,int type_ver,int pnd,const char *imaf,int period_type,class iceb_rnfxml_data *rek_zag_nn,FILE *ff_xml);
-******************/
+
 int iceb_dumpbazout(const char *namebases,const char *login,const char *parol,const char *hostname,GtkWidget *wpredok);
 int iceb_menu_selectfil(class iceb_u_str *imafz,const char *zagolov,GtkWidget *wpredok);
+
 int iceb_system(const char *komanda,GtkTextBuffer *buffer,GtkWidget *view);
+int iceb_system(const char *komanda,class iceb_printw_from_thread_data *data);
+
 void iceb_blokps();
 void iceb_optimbazw(const char *imabaz,GtkWidget *wpredok);
 int iceb_getnkontr(int nom_start,GtkWidget *wpredok);
@@ -462,7 +463,6 @@ int iceb_prov_vdb(const char *namebases,GtkWidget *wpredok);
 
 int iceb_rnl(const char *imaf,int orient,const char *obr,void (*hapka)(int nom,int *kostr,FILE *FF,GtkWidget *wpredok),GtkWidget *wpredok);
 int iceb_rnl(const char *imaf,class iceb_rnl_c *rh,void (*hapka1)(class iceb_rnl_c *rh,int *nom_str,FILE *ff),GtkWidget *wpredok) ;
-//int iceb_rnl(const char *imaf,int orient,const char *obr,void (*hapka)(int nom,int *kostr,FILE *FF),GtkWidget *wpredok);
 
 const char *iceb_getkoddok(short d,short m,short g,int metka);
 const char *iceb_getkoddok(const char *data,int metka);
