@@ -1,9 +1,37 @@
-/*$Id: iceb_printw_vr.c,v 1.11 2013/12/31 11:49:19 sasa Exp $*/
-/*22.05.2016	21.12.2003	Белых А.И.	iceb_printw_vr.c
+/*$Id:$*/
+/*23.12.2025	21.12.2003	Белых А.И.	iceb_printw_vr.c
 Вывод в окно времени расчёта
 */
 #include <math.h>
 #include "iceb_libbuh.h"
+#include "iceb_printw_from_thread.h"
+
+void iceb_printw_vr(time_t vrem_n, //Время начала расчёта
+class iceb_printw_from_thread_data *data)
+{
+time_t vrem_k;
+
+time(&vrem_k);
+
+double kii;
+double dii=(vrem_k-vrem_n)/60.;
+
+dii=modf(dii,&kii);
+
+data->str=g_strdup_printf("%s %.f%s %.f%s\n",
+gettext("Время расчёта"),
+kii,
+gettext("мин."),
+dii*60.,
+gettext("сек."));
+
+iceb_printw_from_thread(data);
+
+
+}
+
+/********************************************/
+/********************************************/
 
 
 void iceb_printw_vr(time_t vrem_n, //Время начала расчёта
