@@ -1,5 +1,5 @@
-/* $Id: zarnastw.c,v 1.31 2014/08/31 06:19:22 sasa Exp $ */
-/*16.11.2016    21.06.2006      Белых А.И.      zarnastw.c
+/* $Id: $ */
+/*26.01.2026    21.06.2006      Белых А.И.      zarnastw.c
 Читаем настройку на зарплату
 */
 #include        "buhg_g.h"
@@ -85,6 +85,12 @@ int kodzv_nat=0;//Код звания неатестованный
 int kekv_nfo=0; //Код экономической классификации для начислений на фонд оплаты
 class iceb_u_str kod_prem_z_kvrt; /*коды премии за квартал*/
 
+/*Переменные для расчёта доли подоходного налога приходящиеся на указанные начисления*/
+/************************/
+class iceb_u_spisok skndr; /*список кодов начисления для любого количества настроек расчёта*/
+class iceb_u_int kudzr;    /*код удержания для каждой строки списка начислений*/
+/************************/
+
 short vplsh; /*0-двух уровневый план счетов 1-многоуровневый*/
 extern SQL_baza bd;
 
@@ -101,6 +107,7 @@ kuprof=metkarnb=0;
 kod_prem_z_kvrt.new_plus("");
 shrpz.new_plus("");
 shrpzbt.new_plus("");
+short metka_skndr=0; /*1-была настройка начислений 0-не была*/
 
 kof_prog_min=ppn=pomzp=0.;
 kekv_at=kekv_nat=kodzv_nat=kekv_nfo=0;
@@ -108,6 +115,12 @@ kekv_at=kekv_nat=kodzv_nat=kekv_nfo=0;
 kodvn=kodvs_b=0;
 kodvn_nvr.new_plus("");
 
+if(kudzr.kolih() > 0)
+ kudzr.free_class(); 
+
+if(skndr.kolih() > 0)
+ skndr.free_class(); 
+
 if(kodkomand != NULL)
  {
   delete [] kodkomand;
@@ -294,6 +307,25 @@ while(cur_alx.read_cursor(&row_alx) != 0)
    continue;
   iceb_u_polen(row_alx[0],&str,1,'|');
 
+  if(iceb_u_SRAV(str.ravno(),"Коды начислений для расчёта доли подоходного налога",0) == 0)
+   {
+    iceb_u_polen(row_alx[0],&bros,2,'|');
+    if(bros.getdlinna() > 1)
+     {
+      skndr.plus(bros.ravno());
+      metka_skndr=1;
+     }
+   }
+  if(iceb_u_SRAV(str.ravno(),"Код удержания для доли подоходного налога",0) == 0)
+   {
+    if(metka_skndr == 1)
+     {
+      iceb_u_polen(row_alx[0],&bros,2,'|');
+      kudzr.plus(bros.ravno_atoi());
+     }
+    metka_skndr=0;
+   }
+
   if(iceb_u_SRAV(str.ravno(),"Код экономической классификации затрат для атестованных",0) == 0)
    {
     iceb_u_polen(row_alx[0],&kekv_at,2,'|');
